// 测试工作频率为11.0592MH：
#include "stc8h.h"
#include "intrins.h"

void main()
{
	P_SW2|= 0x80;

	P1M0 = 0x00;
	P1M1 = 0x00;

	РЗМ0 = 0x00;
	P3M1 = 0x00;
	P5M0 = 0x00;
	P5M1 = 0x00;

	PWMA_CCER1 = 0x00：
	PWMA_CCMR1 = 0x01；
	PWMA_CCMR2 = 0x02；
	PWMA_CCER1 = 0x11；
	PWMA_CCER1 |= 0x00;
	PWMA_CCER1 |= 0x20;
	PWMA_SMCR = 0x54;	// B 0101 0100
	PWMA_CR1 = 0x01;

	PWMA_IER = 0x06; // B 0000 0110

	EA = 1;
	while（1）;
｝

void PWMA_ISR() interrupt 26
{
	unsigned int cnt;
	if (PWMA_SR1 & 0x02)
	{
		PWMA_SR1 &= ~0x02;
		cnt = PWMA_CCR1;
	}

	if (PWMA_SR1 & 0x04)
	{
		PWMA_SR1 &= ~0x04;
		cnt = PWMA_CCR2;
	｝
}


/**
 * 总体思路：
 * PWMA有4个输入通道（PWM1P～PWM4P）
 * 让PWM1P捕捉PWM的上升沿（对应TI1FP1，CC1来计数），计数间隔即为PWM周期长度T_period（T_on + T_off）；
 * 让PWM2P捕捉PWM的下降沿（对应TI1FP2，CC2来计数），与上一次PWM1P的计数间隔即为PWM高电平长度T_on。
*/
void main(void)
{
	P_SW2|= 0x80;

	/**************************** 配置引脚 ****************************/
	// 1、【GPIO】配置PWMA输入捕获对应的引脚（P1.0）为高阻输入
	P1M0 = 0x00; P1M1 = 0x00;

	/**************************** 配置链路 ****************************/
	// 2、【滤波器】设置 PWMA_CCMR1 的 IC1F -> 滤波设为8个时钟数
	PWMA_CCMR1 &= 0x0F;	// B 0000 1111
	PWMA_CCMR1 |= 0x30;	// B 0011 0000

	// 3、【捕获选择】设置 PWMA_CCER1 的 CC1P -> 捕获发生在TI1F的上升沿（对应 TI1FP1），设置 PWMA_CCER1 的 CC2P -> 捕获发生在TI1F的下降沿（对应 TI1FP2）
	PWMA_CCER1 &= 0xFD;	// B 1101 1101
	PWMA_CCER1 |= 0x20;	// B 0010 0000

	// 4、【映射选择】设置 PWMA_CCMR1 的 CC1S -> IC1 映射到 TI1FP1，设置 PWMA_CCMR2的 CC2S -> IC2 映射到 TI1FP2
	PWMA_CCMR1 &= 0xFC;	// B 1111 1100
	PWMA_CCMR1 |= 0x01;	// B 0000 0001

	PWMA_CCMR2 &= 0xFC;	// B 1111 1100
	PWMA_CCMR2 |= 0x02;	// B 0000 0010

	// 5、【从模式】从模式触发动作 -> 触发源选择 TI1FP1, 遇到就复位计数器（这样，每次上升沿都能自动清零计数器，不用进中断，不用软件处理，提高效率）
	PWMA_SMCR = 0x54;	// B 0101 0100

	// 6、【分频系数】设置 PWMA_CCMR1 的 IC1PSC，设置 PWMA_CCMR2 的 IC2PS
	PWMA_CCMR1 &= 0xF3;	// B 1111 0011
	PWMA_CCMR1 |= 0x00;	// B 0000 0000

	PWMA_CCMR2 &= 0xF3;	// B 1111 0011
	PWMA_CCMR2 |= 0x00;	// B 0000 0000

	/**************************** 使能捕捉和计数 ****************************/
	// 7、【使能捕获】设置 PWMA_CCER1 的 CC1E -> 使能 通道1 的输入捕获，设置 PWMA_CCER1的CC2E -> 使能 通道2 的输入捕获
	PWMA_CCER1 &= 0xEE;	// B 1110 1110
	PWMA_CCER1 |= 0x11;	// B 0000 0001

	// 8、【使能计数】设置PWMA_CR1的CENA -> 使能计数器
	PWMA_CCER1 &= 0xEE;	// B 1110 1110
	PWMA_CCER1 |= 0x11;	// B 0000 0001

	while(1);
}





