#include "config_stc.h"

void PWMA_IC_Init()
{
    /**************************** 配置引脚 ****************************/
	// 1、【GPIO】配置PWMA输入捕获 PWM1P通道的引脚及模式（高阻输入），PWM1P -> P1.0
	PWMA_PS &= 0xFC;	// B 1111 1100
    P1M0 &= ~0x01; P1M1 |= 0x01; 	// P1.0

	/**************************** 配置链路 ****************************/
	// 2、【滤波器】设置 PWMA_CCMR1 的 IC1F -> 滤波设为8个时钟数
	PWMA_CCMR1 &= 0x0F;	// B 0000 1111
	PWMA_CCMR1 |= 0x30;	// B 0011 0000

	// 3、【捕获选择】设置 PWMA_CCER1 的 CC1P -> 捕获发生在TI1F的上升沿（对应 TI1FP1），设置 PWMA_CCER1 的 CC2P -> 捕获发生在TI1F的下降沿（对应 TI1FP2）
	PWMA_CCER1 &= 0xFD;	// B 1101 1101
	PWMA_CCER1 |= 0x20;	// B 0010 0000

	// 4、【映射选择】设置 PWMA_CCMR1 的 CC1S -> IC1 映射到 TI1FP1，设置 PWMA_CCMR2的 CC2S -> IC2 映射到 TI1FP2
	PWMA_CCMR1 &= 0xFC;	// B 1111 1100
	PWMA_CCMR1 |= 0x01;	// B 0000 0001

	PWMA_CCMR2 &= 0xFC;	// B 1111 1100
	PWMA_CCMR2 |= 0x02;	// B 0000 0010

	// 5、【从模式】从模式触发动作 -> 触发源选择 TI1FP1, 遇到就复位计数器（这样，每次上升沿都能自动清零计数器，不用进中断，不用软件处理，提高效率）
	PWMA_SMCR = 0x54;	// B 0101 0100

	// 6、【分频系数】设置 PWMA_CCMR1 的 IC1PSC，设置 PWMA_CCMR2 的 IC2PS
	PWMA_CCMR1 &= 0xF3;	// B 1111 0011
    PWMA_CCMR2 &= 0xF3;	// B 1111 0011
}

void PWMA_IC_Start()
{
    /**************************** 使能捕捉和计数 ****************************/
	// 7、【使能捕获】设置 PWMA_CCER1 的 CC1E -> 使能 通道1 的输入捕获，设置 PWMA_CCER1的CC2E -> 使能 通道2 的输入捕获
	PWMA_CCER1 |= 0x11;	// B 0001 0001

	// 8、【使能计数】设置 PWMA_CR1 的 CENA -> 使能计数器
	PWMA_CR1 |= 0x01;	// B 0000 0001
}

void PWMA_IC_Stop()
{
	PWMA_CCER1 &= 0xEE;	// B 1110 1110
    PWMA_CR1 &= 0xFE;	// B 1111 1110
}
