#include <stdio.h>
#include <string.h>
#include "config_stc.h"
#include "OLED128x64.h"
#include "pwma_ic.h"

#define R1_VAL          (uint16_t)(500) 	// 555电路 R1 Ω
#define R2_VAL          (uint16_t)(500) 	// 555电路 R2 Ω
#define PRESCALER_DIV   (uint16_t)(12)      // Timer1 预分频系数

volatile uint16_t TonCnt = 0;   // PWM高电平时长计数值
volatile uint16_t TallCnt = 0;  // PWM周期时长计数值

void Global_Init(void);
void Delay500ms(void);
double Calc_Capacitance(double Freq);

void main(void)
{
    volatile uint16_t TonCnt = 0;
    volatile double PWM_Freq = 0.0;
    volatile double PWM_Duty = 0.0;
    volatile double Capac = 0;
    volatile char sbuf[22] = {0};
    
    // 0.全局初始化
    Global_Init();

    // 1.OLED 初始化并清屏
	OLED_config();
	printf_ascii_10x24(40,5,"  ");
	FillAll(0);

    memset(sbuf, sizeof(sbuf), 0);
    sprintf(sbuf, "[v1]PWM Testing...");
    printf_ascii_6x8(0, 0, sbuf);
    
    TonCnt = (uint8_t)(TH1);
    TonCnt = (TonCnt << 8) + (uint8_t)(TL1);

    // 1.启动PWMA输入捕捉
    PWMA_IC_Init();
    PWMA_IC_Start();
    
	while(1)
	{  
        Delay500ms(); // 让计数器跑一段时间
        
        TallCnt = PWMA_CCR1;    // 两次上升沿之间的计数值
        TonCnt = PWMA_CCR2;     // 上升沿到下降沿之间的计数值

        // 2.计算结果
        PWM_Freq = ((double)MAIN_Fosc / 12) / TallCnt;
        PWM_Duty = ((double)100 * TonCnt) / TallCnt;
        Capac = Calc_Capacitance(PWM_Freq);

        // 3.显示结果
        memset(sbuf, sizeof(sbuf), 0);
        sprintf(sbuf, "PWM Freq[Hz]%.2f", PWM_Freq);
        printf_ascii_6x8(0, 2, sbuf);
        
        memset(sbuf, sizeof(sbuf), 0);
        sprintf(sbuf, "PWM Duty[ %%]%0.f", PWM_Duty);
        printf_ascii_6x8(0, 3, sbuf);
        
        memset(sbuf, sizeof(sbuf), 0);
        sprintf(sbuf, "   Capac[uF]%0.2f", Capac);
        printf_ascii_6x8(0, 4, sbuf);

        memset(sbuf, sizeof(sbuf), 0);
        sprintf(sbuf, "Tall[%u]Ton[%u]", TallCnt, TonCnt);
        printf_ascii_6x8(0, 5, sbuf);
	}
}

double Calc_Capacitance(double Freq)
{
	double Capacitance = 1000000.0 * (1.44 / (Freq * (R1_VAL + 2 * R2_VAL)));	// uF as Default
    return Capacitance;
}  

void Global_Init(void)
{
    P_SW2 |= 0x80;  // 使能访问XFR，没有冲突不用关闭
    
    P0M0 = 0x00;
    P0M1 = 0x00;
    P1M0 = 0x00;
    P1M1 = 0x00;
    P2M0 = 0x00;
    P2M1 = 0x00;
    P3M0 = 0x00;
    P3M1 = 0x00;
    P4M0 = 0x00;
    P4M1 = 0x00;
    P5M0 = 0x00;
    P5M1 = 0x00;
}

void Delay500ms(void)	//@12.000MHz
{
	unsigned char data i, j, k;

	_nop_();
	i = 31;
	j = 113;
	k = 29;
	do
	{
		do
		{
			while (--k);
		} while (--j);
	} while (--i);
}


